@@ -112,6 +112,7 @@ class Marionette(object):
         self.noWindow = noWindow
         self.logcat_dir = logcat_dir
         self.gecko_path = gecko_path
+        self._test_name = None
 
         if bin:
             self.instance = GeckoInstance(host=self.host, port=self.port,
@@ -272,6 +273,15 @@ class Marionette(object):
         self.b2g = 'b2g' in self.session
         return self.session
 
+    @property
+    def test_name(self):
+        return self._test_name
+
+    @test_name.setter
+    def test_name(self, test_name):
+        if self._send_message('setTestName', 'ok', value=test_name):
+            self._test_name = test_name
+
     def delete_session(self):
         response = self._send_message('deleteSession', 'ok')
         self.session = None
@@ -456,9 +466,10 @@ class Marionette(object):
     def get_perf_data(self):
         return self._send_message('getPerfData', 'value')
 
-    def import_script(self, file):
-        f = open(file, "r")
-        js = f.read()
+    def import_script(self, js_file):
+        js = ''
+        with open(js_file, 'r') as f:
+            js = f.read()
         return self._send_message('importScript', 'ok', script=js)
 
     @property
